@@ -2,11 +2,14 @@
 
 module Zeitwerk
   require_relative "zeitwerk/real_mod_name"
+  require_relative "zeitwerk/internal"
   require_relative "zeitwerk/loader"
+  require_relative "zeitwerk/gem_loader"
   require_relative "zeitwerk/registry"
   require_relative "zeitwerk/explicit_namespace"
   require_relative "zeitwerk/inflector"
   require_relative "zeitwerk/gem_inflector"
+  require_relative "zeitwerk/null_inflector"
   require_relative "zeitwerk/kernel"
   require_relative "zeitwerk/error"
   require_relative "zeitwerk/version"
